@@ -16,13 +16,13 @@ our @ISA = qw(Exporter);
 # This allows declaration	use NKTI::general ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw( cetak cetak_r ) ]);
+our %EXPORT_TAGS = ( 'all' => [ qw( cetak cetak_r cetak_pre ) ]);
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our @EXPORT = qw(cetak cetak_r);
+our @EXPORT = qw(cetak cetak_r cetak_pre);
 
 # Define Version :
 # ---------------------------------------------------------------- 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Create Subroutine for Get OS Server Information :
 # ------------------------------------------------------------------------
@@ -30,12 +30,12 @@ our $VERSION = '0.09';
 
     Description Subroutine :
     ----------------------------------------
-    SUbroutine yang berfungsi untuk menampilkan Informasi OS Server.
+    Subroutine yang berfungsi untuk menampilkan Informasi OS Server.
 
     Parameter Subroutine :
     ----------------------------------------
     Tidak ada parameter Subroutine.
-    
+
 =cut
 sub os_server_info {
     # ----------------------------------------------------------------
@@ -76,6 +76,12 @@ sub os_server_info {
 # ------------------------------------------------------------------------
 =head1 SUBROUTINE os_client_info()
 
+    Deskripsi subroutine os_client_info() :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk mendeteksi
+    nama sistem operasi yang digunakan melalui identifikasi
+    request HTTP.
+
     Parameter Subroutine :
     ----------------------------------------
     No Argument or Parameter.
@@ -130,10 +136,15 @@ sub os_info {
 # ------------------------------------------------------------------------
 =head1 SUBROUTINE browser_info()
 
+    Deskripsi subroutine browser_info() :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk mendapatkan
+    informasi browser yang digunakan pada request HTTP.
+
     Parameter Subroutine :
     ----------------------------------------
     No Parameter Subroutine.
-    
+
 =cut
 sub browser_info {
     
@@ -217,7 +228,11 @@ sub delimiter_dir {
 
 # Create Subroutine for get database config :
 # ------------------------------------------------------------------------
-=head1 get_dbconfig()
+=head1 SUBROUTINE get_dbconfig_php()
+
+    Deskripsi subroutine get_dbconfig() :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk database config pada php.
 
     Parameter Subroutine :
     ----------------------------------------
@@ -256,7 +271,7 @@ sub get_dbconfig {
 # Subroutine for get protocols :
 # ------------------------------------------------------------------------
 =head1 SUBROUTINE get_protocol()
-    
+
     Deskripsi subroutine get_protocol() :
     ----------------------------------------
     Subroutine yang berfungsi untuk mengambil data protocol.
@@ -285,9 +300,9 @@ sub get_protocol {
 # End of Subroutine for get protocols.
 # ===========================================================================================================
 
-# Create Module for check IF module is exists :
+# Subroutine for check IF module is exists :
 # ------------------------------------------------------------------------
-=head1 MODULE try_module()
+=head1 SUBROUTINE try_module()
 
     Description Subroutine :
     ----------------------------------------
@@ -321,13 +336,13 @@ sub try_module {
         return(1);
     }
 }
-# End of Create Module for check IF module is exists
+# End of Subroutine for check IF module is exists
 # ===========================================================================================================
 
 # Subroutine for define time for Event MySQL :
 # ------------------------------------------------------------------------
 =head1 SUBROUTINE time_event_mysql()
-    
+
     Deskripsi subroutine time_event_mysql() :
     ---------------------------------------------
     Subroutine yang berfungsi untuk mendefinisikan Time Event MySQL.
@@ -451,12 +466,12 @@ sub time_event_mysql {
 
 # Subroutine for Define format DATETIME MySQL :
 # ------------------------------------------------------------------------
-=head1 SUBRUTINE datetime_mysql()
+=head1 SUBROUTINE datetime_mysql()
 
-	Deskripsi subroutine datetime_mysql() :
-	----------------------------------------
-	Subroutine yang berfungsi untuk mengkonversi "timestamp" ke
-	Format "DATETIME" MySQL.
+    Deskripsi subroutine datetime_mysql() :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk mengkonversi "timestamp" ke
+    Format "DATETIME" MySQL.
 
     Parameter subroutine datetime_mysql() :
     ----------------------------------------
@@ -501,17 +516,17 @@ sub datetime_mysql {
 # ------------------------------------------------------------------------
 =head1 SUBROUITNE cetak()
 
-	Deskripsi subroutine cetak() :
-	----------------------------------------
-	Subroutine yang berfungsi untuk mencetak.
+    Deskripsi subroutine cetak() :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk mencetak.
 
-	Parameter subroutine cetak() :
-	----------------------------------------
-	$data           =>  berisi string yang akan di cetak.
+    Parameter subroutine cetak() :
+    ----------------------------------------
+    $data           =>  berisi string yang akan di cetak.
 
-	Output Parameter :
-	----------------------------------------
-	Hasil cetakan.
+    Output Parameter :
+    ----------------------------------------
+    Hasil cetakan.
 
 =cut
 sub cetak {
@@ -531,17 +546,17 @@ sub cetak {
 # ------------------------------------------------------------------------
 =head1 SUBROUTINE cetak_r()
 
-	Deskripsi subroutine cetak_r() :
-	----------------------------------------
-	Subroutine yang berfungsi untuk mencetak referensi.
+    Deskripsi subroutine cetak_r() :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk mencetak referensi dengan Data::Dumper atau "Dumper"
 
-	Parameter subroutine cetak_r() :
-	----------------------------------------
-	Parameter bisa scalar, array, hash atau referensi.
+    Parameter subroutine cetak_r() :
+    ----------------------------------------
+    Parameter bisa scalar, array, hash atau referensi.
 
-	Output Parameter :
-	----------------------------------------
-	Print Referensi.
+    Output Parameter :
+    ----------------------------------------
+    Print Referensi.
 
 =cut
 sub cetak_r {
@@ -564,24 +579,65 @@ sub cetak_r {
 # End of Subroutine for Print ref.
 # ===========================================================================================================
 
+# Subroutine for print ref with pre tag HTML :
+# ------------------------------------------------------------------------
+=head1 SUBROUTINE cetak_pre()
+
+    Deskripsi subroutine cetak_pre() :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk mencetak dengan Data::Dumper atau "Dumper"
+    beserta tag "<pre>" html.
+
+    Parameter subroutine cetak_pre() :
+    ----------------------------------------
+    Parameter bisa scalar, array, hash atau referensi.
+
+    Output Parameter :
+    ----------------------------------------
+    Print Referensi.
+
+=cut
+sub cetak_pre {
+    # ----------------------------------------------------------------
+    # Check Parameter Subroutine :
+    # ----------------------------------------------------------------
+    if (keys(@_) eq 1) {
+        # ----------------------------------------------------------------
+        # Print Dumper :
+        # ----------------------------------------------------------------
+        print "<pre>";
+        print Dumper $_[0];
+        print "</pre>";
+    }
+    if (keys(@_) > 1) {
+        # ----------------------------------------------------------------
+        # Print Dumper :
+        # ----------------------------------------------------------------
+        print Dumper \@_;
+    }
+}
+# End of Subroutine for print ref with pre tag HTML
+# ===========================================================================================================
+
+
 1;
 __END__
 =head1 NAME
 
-    NKTI::general - The Part of NKTIweb The Simple Web Framework
+NKTI::general - The Part of NKTIweb The Simple Web Framework
 
 =head1 VERSION
 
-    This document describes NKTI::general version 0.09.
+This document describes NKTI::general version 0.10.
 
 =head2 AUTHOR
 
-    Achmad Yusri Afandi, (linuxer08@gmail.com).
+Achmad Yusri Afandi, (linuxer08@gmail.com).
 
 =head2 COPYRIGHT AND LICENSE
 
-    Copyright (c) 2016, Achmad Yusri Afandi, All Rights reserved.
+Copyright (c) 2016, Achmad Yusri Afandi, All Rights reserved.
 
-    Pustaka yang berfungsi untuk hal-hal umum dalam web aplikasi.
+Pustaka yang berfungsi untuk hal-hal umum dalam web aplikasi.
 
 =cut
\ No newline at end of file
