@@ -2,41 +2,19 @@ package NKTI::general::dbconnect;
 
 use strict;
 use warnings;
-use JSON;
+use JSON::XS;
 use DBI;
 
 # Define Version :
 # ----------------------------------------------------------------
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Create Module for Connection MySQL Database :
 # ------------------------------------------------------------------------
-# Module for MySQL Database Connection.
-#
-=head1 MODULE mysql()
-
-		Description Subroutine :
-		----------------------------------------
-		Subroutine untuk koneksi MySQL Database.
-
-    Parameter Modul :
-    ----------------------------------------
-    _db_config =>       Parameter yang berisi hash config database.
-
-=cut
 sub mysql {
-
     # Define parameter Module :
     # ----------------------------------------------------------------
-    my $class = shift;
-    my $self = {
-        _db_config => shift
-    };
-    bless $self, $class;
-
-    # Define scalar for parameter module :
-    # ----------------------------------------------------------------
-    my $get_db_config = $self->{_db_config};
+    my ($self, $get_db_config) = @_;
 
     # Declare scalar for result :
     # ----------------------------------------------------------------
@@ -67,29 +45,11 @@ sub mysql {
 
 # Module for Connection PostgreSQL Database :
 # ------------------------------------------------------------------------
-=head1 MODULE pgsql()
-	
-	Deskripsi subroutne pgsql() :
-	----------------------------------------
-
-	Parameter subroutne pgsql() :
-	----------------------------------------
-	describ_param
-
-=cut
 sub pgsql {
 	# ----------------------------------------------------------------
 	# Defien parameter Subroutine :
 	# ----------------------------------------------------------------
-    my $class = shift;
-    my $self = {
-        _db_config => shift
-    };
-    bless $self, $class;
-    # ----------------------------------------------------------------
-    # Define scalar for parameter module :
-    # ----------------------------------------------------------------
-    my $get_db_config = $self->{_db_config};
+    my ($self, $get_db_config) = @_;
     # ----------------------------------------------------------------
     # Declare scalar for result :
     # ----------------------------------------------------------------
@@ -117,17 +77,6 @@ sub pgsql {
 
 # Create Module for connection SQLite :
 # ------------------------------------------------------------------------
-=head1 MODULE sqlite()
-
-		Description Subroutine :
-		----------------------------------------
-		Subroutine untuk koneksi sqlite Database.
-
-    Parameter Subroutine :
-    ----------------------------------------
-    $fieloc_db      =>  [ Berisi Lokasi file Database ]
-
-=cut
 sub sqlite {
     
     # Define parameter module :
@@ -152,11 +101,183 @@ sub sqlite {
 
 1;
 __END__
+
+=head1 NAME
+
+NKTI::general::dbconnect - Preparing to multiple database connection.
+
+=head1 SYNOPSIS
+
+    use NKTI::general::dbconnect;
+
+    # JSON database config :
+    my $json_dbconfig = '{
+        "db_host" : "localhost",
+        "db_name" : "your_db",
+        "db_user" : "your_userdb",
+        "db_psas" : "your_passUserDb"
+    }';
+
+    # Initialization (example mysql) :
+    my $dbh = NKTI::general::dbconnect->mysql($json_dbconfig);
+
+    # For Disconnected :
+    $dbh->disconnect();
+
+=head1 DESCRIPTION
+
+This module allows the use of multiple database connection database with portable way.
+The purpose of this module is to be easy to use if you want to use more than one database connection easily.
+
+=head1 EXAMPLE 1
+
+    # Example file (db_one.pl) :
+    #!/usr/bin/perl
+    use strict;
+    use warnings;
+    use NKTI::general::dbconnect;
+
+    # Database Config 1 :
+    my $json_dbconfig1 = '{
+        "db_host" : "localhost",
+        "db_name" : "your_db1",
+        "db_user" : "your_userdb1",
+        "db_psas" : "your_passUserDb1"
+    }';
+
+    # Database Config 2 :
+    my $json_dbconfig2 = '{
+        "db_host" : "localhost",
+        "db_name" : "your_db1",
+        "db_user" : "your_userdb1",
+        "db_psas" : "your_passUserDb1"
+    }';
+
+    # Establishe Database Interface 1 :
+    my $dbh = NKTI::general::dbconnect->mysql($json_dbconfig1);
+
+    # Statement Handle :
+    my $sth = $dbh->prepare('SELECT * FROM yourtable');
+    $sth->execute();
+    my $rv = $sth->rows;
+    if ($rv >= 1) {
+
+        # Established Database Interface 2 :
+        my $dbh1 = NKTI::general::dbconnect->mysql($json_dbconfig2);
+
+        # Statement Handle :
+        my $sth1 = $dbh->prepare('SELECT * FROM yourtable');
+        $sth1->execute();
+        my $rv1 = $sth1->rows;
+        if ($rv1 >= 1) {
+            # true action ...
+        } else {
+            # false action ...
+        }
+
+        # Disconnect and Finishing Query 2 :
+        $sth1->finish();
+        $dbh1->disconnect();
+
+    } else {
+        # false action ...
+    }
+
+    # Disconnect and Finishing Query 1 :
+    $sth->finish();
+    $dbh->disconnect();
+
+=head1 EXAMPLE 2
+
+    # Example file (db_two.pl) :
+    #!/usr/bin/perl
+    use strict;
+    use warnings;
+    use NKTI::general::dbconnect;
+
+    # Database Config MySQL :
+    my $json_dbconfig1 = '{
+        "db_host" : "localhost",
+        "db_name" : "your_db1",
+        "db_user" : "your_userdb1",
+        "db_psas" : "your_passUserDb1"
+    }';
+
+    # Database Config SQLite :
+    my $dbconfig_sqlite = '/your/path/sqlite.db';
+
+    # Establishe Database Interface MySQL :
+    my $dbh = NKTI::general::dbconnect->mysql($json_dbconfig1);
+
+    # Statement Handle :
+    my $sth = $dbh->prepare('SELECT * FROM yourtable');
+    $sth->execute();
+    my $rv = $sth->rows;
+    if ($rv >= 1) {
+
+        # Established Database Interface SQLite :
+        my $dbh1 = NKTI::general::dbconnect->sqlite($dbconfig_sqlite);
+
+        # Statement Handle :
+        my $sth1 = $dbh->prepare('SELECT * FROM yourtable');
+        $sth1->execute();
+        my $rv1 = $sth1->rows;
+        if ($rv1 >= 1) {
+            # true action ...
+        } else {
+            # false action ...
+        }
+
+        # Disconnect and Finishing Query SQLite :
+        $sth1->finish();
+        $dbh1->disconnect();
+
+    } else {
+        # false action ...
+    }
+
+    # Disconnect and Finishing Query :
+    $sth->finish();
+    $dbh->disconnect();
+
+=head1 EXPLAIN Subroutine mysql
+
+    Description Subroutine :
+    ----------------------------------------
+    Subroutine untuk koneksi MySQL Database.
+
+    Parameter Subroutine :
+    ----------------------------------------
+    $get_db_config      =>  JSON Format Database config.
+
+=head1 EXPLAIN Subroutine pgsql
+
+	Deskripsi subroutine pgsql() :
+	----------------------------------------
+	Subroutne for PostgreSQL Database Connection.
+
+	Parameter subroutine pgsql() :
+	----------------------------------------
+	$your_dbconifg      =>  JSON Format Database config.
+
+=head2 EXPLAIN Subroutine sqlite
+
+    Description Subroutine :
+    ----------------------------------------
+    Subroutine untuk koneksi sqlite Database.
+
+    Parameter Subroutine :
+    ----------------------------------------
+    $fieloc_db          =>  Location of File database SQLite.
+
 =head1 AUTHOR
-    Achmad Yusri Afandi, (linuxer08@gmail.com)
+
+Achmad Yusri Afandi, (yusrideb@cpan.org)
 
 =head1 COPYRIGHT AND LICENSE
-    Copyright (c) 2016, Achmad Yusri Afandi, All Rights reserved.
 
-    Pustaka yang berfungsi untuk melakukan koneksi database.
+Copyright (c) 2016, Achmad Yusri Afandi, All Rights reserved.
+
+Pustaka yang berfungsi untuk Database Interface.
+
 =cut
\ No newline at end of file
